netapp_ontap.models.lun_movement_progress API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.lun_movement_progress`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class LunMovementProgressSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the LunMovementProgress object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `elapsed GET`

    The amount of time, in seconds, that has elapsed since the start of the LUN movement.

  `failure GET POST PATCH`

    The failure field of the lun_movement_progress.

  `percent_complete GET`

    The percentage complete of the LUN movement.

  `state GET PATCH`

    The state of the LUN movement.
    Valid in PATCH when an LUN movement is active. Set to paused to pause a LUN movement. Set to replicating to resume a paused LUN movement.

    Valid choices:

    - preparing
    - replicating
    - paused
    - paused_error
    - complete
    - reverting
    - failed
  `volume_snapshot_blocked GET`

    This property reports if volume Snapshot copies are blocked by the LUN movement. This property can be polled to identify when volume Snapshot copies can be resumed after beginning a LUN movement.